vfbLib.typing.Component
=======================

.. currentmodule:: vfbLib.typing

.. autoclass:: Component
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Component.__init__
      ~Component.clear
      ~Component.copy
      ~Component.fromkeys
      ~Component.get
      ~Component.items
      ~Component.keys
      ~Component.pop
      ~Component.popitem
      ~Component.setdefault
      ~Component.update
      ~Component.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Component.gid
      ~Component.offsetX
      ~Component.offsetY
      ~Component.scaleX
      ~Component.scaleY
   
   